# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CrossConnectMappingDetails(object):
    """
    For use with Oracle Cloud Infrastructure FastConnect. Each
    :class:`VirtualCircuit` runs on one or
    more cross-connects or cross-connect groups. A `CrossConnectMappingDetails`
    contains the properties for an individual cross-connect or cross-connect group
    associated with a given virtual circuit.

    The details includes information about the cross-connect or
    cross-connect group, the VLAN, and the BGP peering session.
    """

    #: A constant which can be used with the ipv4_bgp_status property of a CrossConnectMappingDetails.
    #: This constant has a value of "UP"
    IPV4_BGP_STATUS_UP = "UP"

    #: A constant which can be used with the ipv4_bgp_status property of a CrossConnectMappingDetails.
    #: This constant has a value of "DOWN"
    IPV4_BGP_STATUS_DOWN = "DOWN"

    #: A constant which can be used with the ipv6_bgp_status property of a CrossConnectMappingDetails.
    #: This constant has a value of "UP"
    IPV6_BGP_STATUS_UP = "UP"

    #: A constant which can be used with the ipv6_bgp_status property of a CrossConnectMappingDetails.
    #: This constant has a value of "DOWN"
    IPV6_BGP_STATUS_DOWN = "DOWN"

    def __init__(self, **kwargs):
        """
        Initializes a new CrossConnectMappingDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param bgp_md5_auth_key:
            The value to assign to the bgp_md5_auth_key property of this CrossConnectMappingDetails.
        :type bgp_md5_auth_key: str

        :param cross_connect_or_cross_connect_group_id:
            The value to assign to the cross_connect_or_cross_connect_group_id property of this CrossConnectMappingDetails.
        :type cross_connect_or_cross_connect_group_id: str

        :param customer_bgp_peering_ip:
            The value to assign to the customer_bgp_peering_ip property of this CrossConnectMappingDetails.
        :type customer_bgp_peering_ip: str

        :param oracle_bgp_peering_ip:
            The value to assign to the oracle_bgp_peering_ip property of this CrossConnectMappingDetails.
        :type oracle_bgp_peering_ip: str

        :param customer_bgp_peering_ipv6:
            The value to assign to the customer_bgp_peering_ipv6 property of this CrossConnectMappingDetails.
        :type customer_bgp_peering_ipv6: str

        :param oracle_bgp_peering_ipv6:
            The value to assign to the oracle_bgp_peering_ipv6 property of this CrossConnectMappingDetails.
        :type oracle_bgp_peering_ipv6: str

        :param vlan:
            The value to assign to the vlan property of this CrossConnectMappingDetails.
        :type vlan: int

        :param ipv4_bgp_status:
            The value to assign to the ipv4_bgp_status property of this CrossConnectMappingDetails.
            Allowed values for this property are: "UP", "DOWN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type ipv4_bgp_status: str

        :param ipv6_bgp_status:
            The value to assign to the ipv6_bgp_status property of this CrossConnectMappingDetails.
            Allowed values for this property are: "UP", "DOWN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type ipv6_bgp_status: str

        """
        self.swagger_types = {
            'bgp_md5_auth_key': 'str',
            'cross_connect_or_cross_connect_group_id': 'str',
            'customer_bgp_peering_ip': 'str',
            'oracle_bgp_peering_ip': 'str',
            'customer_bgp_peering_ipv6': 'str',
            'oracle_bgp_peering_ipv6': 'str',
            'vlan': 'int',
            'ipv4_bgp_status': 'str',
            'ipv6_bgp_status': 'str'
        }

        self.attribute_map = {
            'bgp_md5_auth_key': 'bgpMd5AuthKey',
            'cross_connect_or_cross_connect_group_id': 'crossConnectOrCrossConnectGroupId',
            'customer_bgp_peering_ip': 'customerBgpPeeringIp',
            'oracle_bgp_peering_ip': 'oracleBgpPeeringIp',
            'customer_bgp_peering_ipv6': 'customerBgpPeeringIpv6',
            'oracle_bgp_peering_ipv6': 'oracleBgpPeeringIpv6',
            'vlan': 'vlan',
            'ipv4_bgp_status': 'ipv4BgpStatus',
            'ipv6_bgp_status': 'ipv6BgpStatus'
        }

        self._bgp_md5_auth_key = None
        self._cross_connect_or_cross_connect_group_id = None
        self._customer_bgp_peering_ip = None
        self._oracle_bgp_peering_ip = None
        self._customer_bgp_peering_ipv6 = None
        self._oracle_bgp_peering_ipv6 = None
        self._vlan = None
        self._ipv4_bgp_status = None
        self._ipv6_bgp_status = None

    @property
    def bgp_md5_auth_key(self):
        """
        Gets the bgp_md5_auth_key of this CrossConnectMappingDetails.
        The key for BGP MD5 authentication. Only applicable if your system
        requires MD5 authentication. If empty or not set (null), that
        means you don't use BGP MD5 authentication.


        :return: The bgp_md5_auth_key of this CrossConnectMappingDetails.
        :rtype: str
        """
        return self._bgp_md5_auth_key

    @bgp_md5_auth_key.setter
    def bgp_md5_auth_key(self, bgp_md5_auth_key):
        """
        Sets the bgp_md5_auth_key of this CrossConnectMappingDetails.
        The key for BGP MD5 authentication. Only applicable if your system
        requires MD5 authentication. If empty or not set (null), that
        means you don't use BGP MD5 authentication.


        :param bgp_md5_auth_key: The bgp_md5_auth_key of this CrossConnectMappingDetails.
        :type: str
        """
        self._bgp_md5_auth_key = bgp_md5_auth_key

    @property
    def cross_connect_or_cross_connect_group_id(self):
        """
        Gets the cross_connect_or_cross_connect_group_id of this CrossConnectMappingDetails.
        The OCID of the cross-connect or cross-connect group for this mapping.
        Specified by the owner of the cross-connect or cross-connect group (the
        customer if the customer is colocated with Oracle, or the provider if the
        customer is connecting via provider).


        :return: The cross_connect_or_cross_connect_group_id of this CrossConnectMappingDetails.
        :rtype: str
        """
        return self._cross_connect_or_cross_connect_group_id

    @cross_connect_or_cross_connect_group_id.setter
    def cross_connect_or_cross_connect_group_id(self, cross_connect_or_cross_connect_group_id):
        """
        Sets the cross_connect_or_cross_connect_group_id of this CrossConnectMappingDetails.
        The OCID of the cross-connect or cross-connect group for this mapping.
        Specified by the owner of the cross-connect or cross-connect group (the
        customer if the customer is colocated with Oracle, or the provider if the
        customer is connecting via provider).


        :param cross_connect_or_cross_connect_group_id: The cross_connect_or_cross_connect_group_id of this CrossConnectMappingDetails.
        :type: str
        """
        self._cross_connect_or_cross_connect_group_id = cross_connect_or_cross_connect_group_id

    @property
    def customer_bgp_peering_ip(self):
        """
        Gets the customer_bgp_peering_ip of this CrossConnectMappingDetails.
        The BGP IPv4 address for the router on the other end of the BGP session from
        Oracle. Specified by the owner of that router. If the session goes from Oracle
        to a customer, this is the BGP IPv4 address of the customer's edge router. If the
        session goes from Oracle to a provider, this is the BGP IPv4 address of the
        provider's edge router. Must use a /30 or /31 subnet mask.

        There's one exception: for a public virtual circuit, Oracle specifies the BGP IPv4 addresses.

        Example: `10.0.0.18/31`


        :return: The customer_bgp_peering_ip of this CrossConnectMappingDetails.
        :rtype: str
        """
        return self._customer_bgp_peering_ip

    @customer_bgp_peering_ip.setter
    def customer_bgp_peering_ip(self, customer_bgp_peering_ip):
        """
        Sets the customer_bgp_peering_ip of this CrossConnectMappingDetails.
        The BGP IPv4 address for the router on the other end of the BGP session from
        Oracle. Specified by the owner of that router. If the session goes from Oracle
        to a customer, this is the BGP IPv4 address of the customer's edge router. If the
        session goes from Oracle to a provider, this is the BGP IPv4 address of the
        provider's edge router. Must use a /30 or /31 subnet mask.

        There's one exception: for a public virtual circuit, Oracle specifies the BGP IPv4 addresses.

        Example: `10.0.0.18/31`


        :param customer_bgp_peering_ip: The customer_bgp_peering_ip of this CrossConnectMappingDetails.
        :type: str
        """
        self._customer_bgp_peering_ip = customer_bgp_peering_ip

    @property
    def oracle_bgp_peering_ip(self):
        """
        Gets the oracle_bgp_peering_ip of this CrossConnectMappingDetails.
        The IPv4 address for Oracle's end of the BGP session. Must use a /30 or /31
        subnet mask. If the session goes from Oracle to a customer's edge router,
        the customer specifies this information. If the session goes from Oracle to
        a provider's edge router, the provider specifies this.

        There's one exception: for a public virtual circuit, Oracle specifies the BGP IPv4 addresses.

        Example: `10.0.0.19/31`


        :return: The oracle_bgp_peering_ip of this CrossConnectMappingDetails.
        :rtype: str
        """
        return self._oracle_bgp_peering_ip

    @oracle_bgp_peering_ip.setter
    def oracle_bgp_peering_ip(self, oracle_bgp_peering_ip):
        """
        Sets the oracle_bgp_peering_ip of this CrossConnectMappingDetails.
        The IPv4 address for Oracle's end of the BGP session. Must use a /30 or /31
        subnet mask. If the session goes from Oracle to a customer's edge router,
        the customer specifies this information. If the session goes from Oracle to
        a provider's edge router, the provider specifies this.

        There's one exception: for a public virtual circuit, Oracle specifies the BGP IPv4 addresses.

        Example: `10.0.0.19/31`


        :param oracle_bgp_peering_ip: The oracle_bgp_peering_ip of this CrossConnectMappingDetails.
        :type: str
        """
        self._oracle_bgp_peering_ip = oracle_bgp_peering_ip

    @property
    def customer_bgp_peering_ipv6(self):
        """
        Gets the customer_bgp_peering_ipv6 of this CrossConnectMappingDetails.
        The BGP IPv6 address for the router on the other end of the BGP session from
        Oracle. Specified by the owner of that router. If the session goes from Oracle
        to a customer, this is the BGP IPv6 address of the customer's edge router. If the
        session goes from Oracle to a provider, this is the BGP IPv6 address of the
        provider's edge router. Only subnet masks from /64 up to /127 are allowed.

        There's one exception: for a public virtual circuit, Oracle specifies the BGP IPv6 addresses.

        Example: `2001:db8::1/64`


        :return: The customer_bgp_peering_ipv6 of this CrossConnectMappingDetails.
        :rtype: str
        """
        return self._customer_bgp_peering_ipv6

    @customer_bgp_peering_ipv6.setter
    def customer_bgp_peering_ipv6(self, customer_bgp_peering_ipv6):
        """
        Sets the customer_bgp_peering_ipv6 of this CrossConnectMappingDetails.
        The BGP IPv6 address for the router on the other end of the BGP session from
        Oracle. Specified by the owner of that router. If the session goes from Oracle
        to a customer, this is the BGP IPv6 address of the customer's edge router. If the
        session goes from Oracle to a provider, this is the BGP IPv6 address of the
        provider's edge router. Only subnet masks from /64 up to /127 are allowed.

        There's one exception: for a public virtual circuit, Oracle specifies the BGP IPv6 addresses.

        Example: `2001:db8::1/64`


        :param customer_bgp_peering_ipv6: The customer_bgp_peering_ipv6 of this CrossConnectMappingDetails.
        :type: str
        """
        self._customer_bgp_peering_ipv6 = customer_bgp_peering_ipv6

    @property
    def oracle_bgp_peering_ipv6(self):
        """
        Gets the oracle_bgp_peering_ipv6 of this CrossConnectMappingDetails.
        The IPv6 address for Oracle's end of the BGP session. Only subnet masks from /64 up to /127 are allowed.
        If the session goes from Oracle to a customer's edge router,
        the customer specifies this information. If the session goes from Oracle to
        a provider's edge router, the provider specifies this.

        There's one exception: for a public virtual circuit, Oracle specifies the BGP IPv6 addresses.

        Example: `2001:db8::2/64`


        :return: The oracle_bgp_peering_ipv6 of this CrossConnectMappingDetails.
        :rtype: str
        """
        return self._oracle_bgp_peering_ipv6

    @oracle_bgp_peering_ipv6.setter
    def oracle_bgp_peering_ipv6(self, oracle_bgp_peering_ipv6):
        """
        Sets the oracle_bgp_peering_ipv6 of this CrossConnectMappingDetails.
        The IPv6 address for Oracle's end of the BGP session. Only subnet masks from /64 up to /127 are allowed.
        If the session goes from Oracle to a customer's edge router,
        the customer specifies this information. If the session goes from Oracle to
        a provider's edge router, the provider specifies this.

        There's one exception: for a public virtual circuit, Oracle specifies the BGP IPv6 addresses.

        Example: `2001:db8::2/64`


        :param oracle_bgp_peering_ipv6: The oracle_bgp_peering_ipv6 of this CrossConnectMappingDetails.
        :type: str
        """
        self._oracle_bgp_peering_ipv6 = oracle_bgp_peering_ipv6

    @property
    def vlan(self):
        """
        Gets the vlan of this CrossConnectMappingDetails.
        The number of the specific VLAN (on the cross-connect or cross-connect group)
        that is assigned to this virtual circuit. Specified by the owner of the cross-connect
        or cross-connect group (the customer if the customer is colocated with Oracle, or
        the provider if the customer is connecting via provider).

        Example: `200`


        :return: The vlan of this CrossConnectMappingDetails.
        :rtype: int
        """
        return self._vlan

    @vlan.setter
    def vlan(self, vlan):
        """
        Sets the vlan of this CrossConnectMappingDetails.
        The number of the specific VLAN (on the cross-connect or cross-connect group)
        that is assigned to this virtual circuit. Specified by the owner of the cross-connect
        or cross-connect group (the customer if the customer is colocated with Oracle, or
        the provider if the customer is connecting via provider).

        Example: `200`


        :param vlan: The vlan of this CrossConnectMappingDetails.
        :type: int
        """
        self._vlan = vlan

    @property
    def ipv4_bgp_status(self):
        """
        Gets the ipv4_bgp_status of this CrossConnectMappingDetails.
        The state of the Ipv4 BGP session.

        Allowed values for this property are: "UP", "DOWN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The ipv4_bgp_status of this CrossConnectMappingDetails.
        :rtype: str
        """
        return self._ipv4_bgp_status

    @ipv4_bgp_status.setter
    def ipv4_bgp_status(self, ipv4_bgp_status):
        """
        Sets the ipv4_bgp_status of this CrossConnectMappingDetails.
        The state of the Ipv4 BGP session.


        :param ipv4_bgp_status: The ipv4_bgp_status of this CrossConnectMappingDetails.
        :type: str
        """
        allowed_values = ["UP", "DOWN"]
        if not value_allowed_none_or_none_sentinel(ipv4_bgp_status, allowed_values):
            ipv4_bgp_status = 'UNKNOWN_ENUM_VALUE'
        self._ipv4_bgp_status = ipv4_bgp_status

    @property
    def ipv6_bgp_status(self):
        """
        Gets the ipv6_bgp_status of this CrossConnectMappingDetails.
        The state of the Ipv6 BGP session.

        Allowed values for this property are: "UP", "DOWN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The ipv6_bgp_status of this CrossConnectMappingDetails.
        :rtype: str
        """
        return self._ipv6_bgp_status

    @ipv6_bgp_status.setter
    def ipv6_bgp_status(self, ipv6_bgp_status):
        """
        Sets the ipv6_bgp_status of this CrossConnectMappingDetails.
        The state of the Ipv6 BGP session.


        :param ipv6_bgp_status: The ipv6_bgp_status of this CrossConnectMappingDetails.
        :type: str
        """
        allowed_values = ["UP", "DOWN"]
        if not value_allowed_none_or_none_sentinel(ipv6_bgp_status, allowed_values):
            ipv6_bgp_status = 'UNKNOWN_ENUM_VALUE'
        self._ipv6_bgp_status = ipv6_bgp_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TaskSchedule(object):
    """
    A model that holds Schedule and other information required for scheduling a task.
    """

    #: A constant which can be used with the retry_delay_unit property of a TaskSchedule.
    #: This constant has a value of "SECONDS"
    RETRY_DELAY_UNIT_SECONDS = "SECONDS"

    #: A constant which can be used with the retry_delay_unit property of a TaskSchedule.
    #: This constant has a value of "MINUTES"
    RETRY_DELAY_UNIT_MINUTES = "MINUTES"

    #: A constant which can be used with the retry_delay_unit property of a TaskSchedule.
    #: This constant has a value of "HOURS"
    RETRY_DELAY_UNIT_HOURS = "HOURS"

    #: A constant which can be used with the retry_delay_unit property of a TaskSchedule.
    #: This constant has a value of "DAYS"
    RETRY_DELAY_UNIT_DAYS = "DAYS"

    #: A constant which can be used with the auth_mode property of a TaskSchedule.
    #: This constant has a value of "OBO"
    AUTH_MODE_OBO = "OBO"

    #: A constant which can be used with the auth_mode property of a TaskSchedule.
    #: This constant has a value of "RESOURCE_PRINCIPAL"
    AUTH_MODE_RESOURCE_PRINCIPAL = "RESOURCE_PRINCIPAL"

    #: A constant which can be used with the auth_mode property of a TaskSchedule.
    #: This constant has a value of "USER_CERTIFICATE"
    AUTH_MODE_USER_CERTIFICATE = "USER_CERTIFICATE"

    #: A constant which can be used with the expected_duration_unit property of a TaskSchedule.
    #: This constant has a value of "SECONDS"
    EXPECTED_DURATION_UNIT_SECONDS = "SECONDS"

    #: A constant which can be used with the expected_duration_unit property of a TaskSchedule.
    #: This constant has a value of "MINUTES"
    EXPECTED_DURATION_UNIT_MINUTES = "MINUTES"

    #: A constant which can be used with the expected_duration_unit property of a TaskSchedule.
    #: This constant has a value of "HOURS"
    EXPECTED_DURATION_UNIT_HOURS = "HOURS"

    #: A constant which can be used with the expected_duration_unit property of a TaskSchedule.
    #: This constant has a value of "DAYS"
    EXPECTED_DURATION_UNIT_DAYS = "DAYS"

    def __init__(self, **kwargs):
        """
        Initializes a new TaskSchedule object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this TaskSchedule.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this TaskSchedule.
        :type model_version: str

        :param model_type:
            The value to assign to the model_type property of this TaskSchedule.
        :type model_type: str

        :param parent_ref:
            The value to assign to the parent_ref property of this TaskSchedule.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this TaskSchedule.
        :type name: str

        :param description:
            The value to assign to the description property of this TaskSchedule.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this TaskSchedule.
        :type object_version: int

        :param object_status:
            The value to assign to the object_status property of this TaskSchedule.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this TaskSchedule.
        :type identifier: str

        :param schedule_ref:
            The value to assign to the schedule_ref property of this TaskSchedule.
        :type schedule_ref: oci.data_integration.models.Schedule

        :param config_provider_delegate:
            The value to assign to the config_provider_delegate property of this TaskSchedule.
        :type config_provider_delegate: oci.data_integration.models.ConfigProvider

        :param is_enabled:
            The value to assign to the is_enabled property of this TaskSchedule.
        :type is_enabled: bool

        :param retry_attempts:
            The value to assign to the retry_attempts property of this TaskSchedule.
        :type retry_attempts: int

        :param retry_delay_unit:
            The value to assign to the retry_delay_unit property of this TaskSchedule.
            Allowed values for this property are: "SECONDS", "MINUTES", "HOURS", "DAYS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type retry_delay_unit: str

        :param retry_delay:
            The value to assign to the retry_delay property of this TaskSchedule.
        :type retry_delay: float

        :param start_time_millis:
            The value to assign to the start_time_millis property of this TaskSchedule.
        :type start_time_millis: int

        :param end_time_millis:
            The value to assign to the end_time_millis property of this TaskSchedule.
        :type end_time_millis: int

        :param is_concurrent_allowed:
            The value to assign to the is_concurrent_allowed property of this TaskSchedule.
        :type is_concurrent_allowed: bool

        :param is_backfill_enabled:
            The value to assign to the is_backfill_enabled property of this TaskSchedule.
        :type is_backfill_enabled: bool

        :param auth_mode:
            The value to assign to the auth_mode property of this TaskSchedule.
            Allowed values for this property are: "OBO", "RESOURCE_PRINCIPAL", "USER_CERTIFICATE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type auth_mode: str

        :param expected_duration:
            The value to assign to the expected_duration property of this TaskSchedule.
        :type expected_duration: float

        :param expected_duration_unit:
            The value to assign to the expected_duration_unit property of this TaskSchedule.
            Allowed values for this property are: "SECONDS", "MINUTES", "HOURS", "DAYS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type expected_duration_unit: str

        :param last_run_details:
            The value to assign to the last_run_details property of this TaskSchedule.
        :type last_run_details: oci.data_integration.models.LastRunDetails

        :param metadata:
            The value to assign to the metadata property of this TaskSchedule.
        :type metadata: oci.data_integration.models.ObjectMetadata

        """
        self.swagger_types = {
            'key': 'str',
            'model_version': 'str',
            'model_type': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'object_status': 'int',
            'identifier': 'str',
            'schedule_ref': 'Schedule',
            'config_provider_delegate': 'ConfigProvider',
            'is_enabled': 'bool',
            'retry_attempts': 'int',
            'retry_delay_unit': 'str',
            'retry_delay': 'float',
            'start_time_millis': 'int',
            'end_time_millis': 'int',
            'is_concurrent_allowed': 'bool',
            'is_backfill_enabled': 'bool',
            'auth_mode': 'str',
            'expected_duration': 'float',
            'expected_duration_unit': 'str',
            'last_run_details': 'LastRunDetails',
            'metadata': 'ObjectMetadata'
        }

        self.attribute_map = {
            'key': 'key',
            'model_version': 'modelVersion',
            'model_type': 'modelType',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'schedule_ref': 'scheduleRef',
            'config_provider_delegate': 'configProviderDelegate',
            'is_enabled': 'isEnabled',
            'retry_attempts': 'retryAttempts',
            'retry_delay_unit': 'retryDelayUnit',
            'retry_delay': 'retryDelay',
            'start_time_millis': 'startTimeMillis',
            'end_time_millis': 'endTimeMillis',
            'is_concurrent_allowed': 'isConcurrentAllowed',
            'is_backfill_enabled': 'isBackfillEnabled',
            'auth_mode': 'authMode',
            'expected_duration': 'expectedDuration',
            'expected_duration_unit': 'expectedDurationUnit',
            'last_run_details': 'lastRunDetails',
            'metadata': 'metadata'
        }

        self._key = None
        self._model_version = None
        self._model_type = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._object_status = None
        self._identifier = None
        self._schedule_ref = None
        self._config_provider_delegate = None
        self._is_enabled = None
        self._retry_attempts = None
        self._retry_delay_unit = None
        self._retry_delay = None
        self._start_time_millis = None
        self._end_time_millis = None
        self._is_concurrent_allowed = None
        self._is_backfill_enabled = None
        self._auth_mode = None
        self._expected_duration = None
        self._expected_duration_unit = None
        self._last_run_details = None
        self._metadata = None

    @property
    def key(self):
        """
        Gets the key of this TaskSchedule.
        Generated key that can be used in API calls to identify taskSchedule. On scenarios where reference to the taskSchedule is needed, a value can be passed in create.


        :return: The key of this TaskSchedule.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this TaskSchedule.
        Generated key that can be used in API calls to identify taskSchedule. On scenarios where reference to the taskSchedule is needed, a value can be passed in create.


        :param key: The key of this TaskSchedule.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this TaskSchedule.
        This is a version number that is used by the service to upgrade objects if needed through releases of the service.


        :return: The model_version of this TaskSchedule.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this TaskSchedule.
        This is a version number that is used by the service to upgrade objects if needed through releases of the service.


        :param model_version: The model_version of this TaskSchedule.
        :type: str
        """
        self._model_version = model_version

    @property
    def model_type(self):
        """
        Gets the model_type of this TaskSchedule.
        The type of the object.


        :return: The model_type of this TaskSchedule.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this TaskSchedule.
        The type of the object.


        :param model_type: The model_type of this TaskSchedule.
        :type: str
        """
        self._model_type = model_type

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this TaskSchedule.

        :return: The parent_ref of this TaskSchedule.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this TaskSchedule.

        :param parent_ref: The parent_ref of this TaskSchedule.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        Gets the name of this TaskSchedule.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this TaskSchedule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TaskSchedule.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this TaskSchedule.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this TaskSchedule.
        Detailed description for the object.


        :return: The description of this TaskSchedule.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this TaskSchedule.
        Detailed description for the object.


        :param description: The description of this TaskSchedule.
        :type: str
        """
        self._description = description

    @property
    def object_version(self):
        """
        Gets the object_version of this TaskSchedule.
        This is used by the service for optimistic locking of the object, to prevent multiple users from simultaneously updating the object.


        :return: The object_version of this TaskSchedule.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this TaskSchedule.
        This is used by the service for optimistic locking of the object, to prevent multiple users from simultaneously updating the object.


        :param object_version: The object_version of this TaskSchedule.
        :type: int
        """
        self._object_version = object_version

    @property
    def object_status(self):
        """
        Gets the object_status of this TaskSchedule.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this TaskSchedule.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this TaskSchedule.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this TaskSchedule.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        Gets the identifier of this TaskSchedule.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this TaskSchedule.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this TaskSchedule.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this TaskSchedule.
        :type: str
        """
        self._identifier = identifier

    @property
    def schedule_ref(self):
        """
        Gets the schedule_ref of this TaskSchedule.

        :return: The schedule_ref of this TaskSchedule.
        :rtype: oci.data_integration.models.Schedule
        """
        return self._schedule_ref

    @schedule_ref.setter
    def schedule_ref(self, schedule_ref):
        """
        Sets the schedule_ref of this TaskSchedule.

        :param schedule_ref: The schedule_ref of this TaskSchedule.
        :type: oci.data_integration.models.Schedule
        """
        self._schedule_ref = schedule_ref

    @property
    def config_provider_delegate(self):
        """
        Gets the config_provider_delegate of this TaskSchedule.

        :return: The config_provider_delegate of this TaskSchedule.
        :rtype: oci.data_integration.models.ConfigProvider
        """
        return self._config_provider_delegate

    @config_provider_delegate.setter
    def config_provider_delegate(self, config_provider_delegate):
        """
        Sets the config_provider_delegate of this TaskSchedule.

        :param config_provider_delegate: The config_provider_delegate of this TaskSchedule.
        :type: oci.data_integration.models.ConfigProvider
        """
        self._config_provider_delegate = config_provider_delegate

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this TaskSchedule.
        Whether the schedule is enabled.


        :return: The is_enabled of this TaskSchedule.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this TaskSchedule.
        Whether the schedule is enabled.


        :param is_enabled: The is_enabled of this TaskSchedule.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def retry_attempts(self):
        """
        Gets the retry_attempts of this TaskSchedule.
        The number of retry attempts.


        :return: The retry_attempts of this TaskSchedule.
        :rtype: int
        """
        return self._retry_attempts

    @retry_attempts.setter
    def retry_attempts(self, retry_attempts):
        """
        Sets the retry_attempts of this TaskSchedule.
        The number of retry attempts.


        :param retry_attempts: The retry_attempts of this TaskSchedule.
        :type: int
        """
        self._retry_attempts = retry_attempts

    @property
    def retry_delay_unit(self):
        """
        Gets the retry_delay_unit of this TaskSchedule.
        The unit for the retry delay.

        Allowed values for this property are: "SECONDS", "MINUTES", "HOURS", "DAYS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The retry_delay_unit of this TaskSchedule.
        :rtype: str
        """
        return self._retry_delay_unit

    @retry_delay_unit.setter
    def retry_delay_unit(self, retry_delay_unit):
        """
        Sets the retry_delay_unit of this TaskSchedule.
        The unit for the retry delay.


        :param retry_delay_unit: The retry_delay_unit of this TaskSchedule.
        :type: str
        """
        allowed_values = ["SECONDS", "MINUTES", "HOURS", "DAYS"]
        if not value_allowed_none_or_none_sentinel(retry_delay_unit, allowed_values):
            retry_delay_unit = 'UNKNOWN_ENUM_VALUE'
        self._retry_delay_unit = retry_delay_unit

    @property
    def retry_delay(self):
        """
        Gets the retry_delay of this TaskSchedule.
        The retry delay, the unit for measurement is in the property retry delay unit.


        :return: The retry_delay of this TaskSchedule.
        :rtype: float
        """
        return self._retry_delay

    @retry_delay.setter
    def retry_delay(self, retry_delay):
        """
        Sets the retry_delay of this TaskSchedule.
        The retry delay, the unit for measurement is in the property retry delay unit.


        :param retry_delay: The retry_delay of this TaskSchedule.
        :type: float
        """
        self._retry_delay = retry_delay

    @property
    def start_time_millis(self):
        """
        Gets the start_time_millis of this TaskSchedule.
        The start time in milliseconds.


        :return: The start_time_millis of this TaskSchedule.
        :rtype: int
        """
        return self._start_time_millis

    @start_time_millis.setter
    def start_time_millis(self, start_time_millis):
        """
        Sets the start_time_millis of this TaskSchedule.
        The start time in milliseconds.


        :param start_time_millis: The start_time_millis of this TaskSchedule.
        :type: int
        """
        self._start_time_millis = start_time_millis

    @property
    def end_time_millis(self):
        """
        Gets the end_time_millis of this TaskSchedule.
        The end time in milliseconds.


        :return: The end_time_millis of this TaskSchedule.
        :rtype: int
        """
        return self._end_time_millis

    @end_time_millis.setter
    def end_time_millis(self, end_time_millis):
        """
        Sets the end_time_millis of this TaskSchedule.
        The end time in milliseconds.


        :param end_time_millis: The end_time_millis of this TaskSchedule.
        :type: int
        """
        self._end_time_millis = end_time_millis

    @property
    def is_concurrent_allowed(self):
        """
        Gets the is_concurrent_allowed of this TaskSchedule.
        Whether the same task can be executed concurrently.


        :return: The is_concurrent_allowed of this TaskSchedule.
        :rtype: bool
        """
        return self._is_concurrent_allowed

    @is_concurrent_allowed.setter
    def is_concurrent_allowed(self, is_concurrent_allowed):
        """
        Sets the is_concurrent_allowed of this TaskSchedule.
        Whether the same task can be executed concurrently.


        :param is_concurrent_allowed: The is_concurrent_allowed of this TaskSchedule.
        :type: bool
        """
        self._is_concurrent_allowed = is_concurrent_allowed

    @property
    def is_backfill_enabled(self):
        """
        Gets the is_backfill_enabled of this TaskSchedule.
        Whether the backfill is enabled


        :return: The is_backfill_enabled of this TaskSchedule.
        :rtype: bool
        """
        return self._is_backfill_enabled

    @is_backfill_enabled.setter
    def is_backfill_enabled(self, is_backfill_enabled):
        """
        Sets the is_backfill_enabled of this TaskSchedule.
        Whether the backfill is enabled


        :param is_backfill_enabled: The is_backfill_enabled of this TaskSchedule.
        :type: bool
        """
        self._is_backfill_enabled = is_backfill_enabled

    @property
    def auth_mode(self):
        """
        Gets the auth_mode of this TaskSchedule.
        The authorization mode for the task.

        Allowed values for this property are: "OBO", "RESOURCE_PRINCIPAL", "USER_CERTIFICATE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The auth_mode of this TaskSchedule.
        :rtype: str
        """
        return self._auth_mode

    @auth_mode.setter
    def auth_mode(self, auth_mode):
        """
        Sets the auth_mode of this TaskSchedule.
        The authorization mode for the task.


        :param auth_mode: The auth_mode of this TaskSchedule.
        :type: str
        """
        allowed_values = ["OBO", "RESOURCE_PRINCIPAL", "USER_CERTIFICATE"]
        if not value_allowed_none_or_none_sentinel(auth_mode, allowed_values):
            auth_mode = 'UNKNOWN_ENUM_VALUE'
        self._auth_mode = auth_mode

    @property
    def expected_duration(self):
        """
        Gets the expected_duration of this TaskSchedule.
        The expected duration of the task execution.


        :return: The expected_duration of this TaskSchedule.
        :rtype: float
        """
        return self._expected_duration

    @expected_duration.setter
    def expected_duration(self, expected_duration):
        """
        Sets the expected_duration of this TaskSchedule.
        The expected duration of the task execution.


        :param expected_duration: The expected_duration of this TaskSchedule.
        :type: float
        """
        self._expected_duration = expected_duration

    @property
    def expected_duration_unit(self):
        """
        Gets the expected_duration_unit of this TaskSchedule.
        The expected duration unit of the task execution.

        Allowed values for this property are: "SECONDS", "MINUTES", "HOURS", "DAYS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The expected_duration_unit of this TaskSchedule.
        :rtype: str
        """
        return self._expected_duration_unit

    @expected_duration_unit.setter
    def expected_duration_unit(self, expected_duration_unit):
        """
        Sets the expected_duration_unit of this TaskSchedule.
        The expected duration unit of the task execution.


        :param expected_duration_unit: The expected_duration_unit of this TaskSchedule.
        :type: str
        """
        allowed_values = ["SECONDS", "MINUTES", "HOURS", "DAYS"]
        if not value_allowed_none_or_none_sentinel(expected_duration_unit, allowed_values):
            expected_duration_unit = 'UNKNOWN_ENUM_VALUE'
        self._expected_duration_unit = expected_duration_unit

    @property
    def last_run_details(self):
        """
        Gets the last_run_details of this TaskSchedule.

        :return: The last_run_details of this TaskSchedule.
        :rtype: oci.data_integration.models.LastRunDetails
        """
        return self._last_run_details

    @last_run_details.setter
    def last_run_details(self, last_run_details):
        """
        Sets the last_run_details of this TaskSchedule.

        :param last_run_details: The last_run_details of this TaskSchedule.
        :type: oci.data_integration.models.LastRunDetails
        """
        self._last_run_details = last_run_details

    @property
    def metadata(self):
        """
        Gets the metadata of this TaskSchedule.

        :return: The metadata of this TaskSchedule.
        :rtype: oci.data_integration.models.ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this TaskSchedule.

        :param metadata: The metadata of this TaskSchedule.
        :type: oci.data_integration.models.ObjectMetadata
        """
        self._metadata = metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class KeyVersion(object):
    """
    KeyVersion model.
    """

    #: A constant which can be used with the lifecycle_state property of a KeyVersion.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a KeyVersion.
    #: This constant has a value of "ENABLING"
    LIFECYCLE_STATE_ENABLING = "ENABLING"

    #: A constant which can be used with the lifecycle_state property of a KeyVersion.
    #: This constant has a value of "ENABLED"
    LIFECYCLE_STATE_ENABLED = "ENABLED"

    #: A constant which can be used with the lifecycle_state property of a KeyVersion.
    #: This constant has a value of "DISABLING"
    LIFECYCLE_STATE_DISABLING = "DISABLING"

    #: A constant which can be used with the lifecycle_state property of a KeyVersion.
    #: This constant has a value of "DISABLED"
    LIFECYCLE_STATE_DISABLED = "DISABLED"

    #: A constant which can be used with the lifecycle_state property of a KeyVersion.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a KeyVersion.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a KeyVersion.
    #: This constant has a value of "PENDING_DELETION"
    LIFECYCLE_STATE_PENDING_DELETION = "PENDING_DELETION"

    #: A constant which can be used with the lifecycle_state property of a KeyVersion.
    #: This constant has a value of "SCHEDULING_DELETION"
    LIFECYCLE_STATE_SCHEDULING_DELETION = "SCHEDULING_DELETION"

    #: A constant which can be used with the lifecycle_state property of a KeyVersion.
    #: This constant has a value of "CANCELLING_DELETION"
    LIFECYCLE_STATE_CANCELLING_DELETION = "CANCELLING_DELETION"

    #: A constant which can be used with the origin property of a KeyVersion.
    #: This constant has a value of "INTERNAL"
    ORIGIN_INTERNAL = "INTERNAL"

    #: A constant which can be used with the origin property of a KeyVersion.
    #: This constant has a value of "EXTERNAL"
    ORIGIN_EXTERNAL = "EXTERNAL"

    def __init__(self, **kwargs):
        """
        Initializes a new KeyVersion object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this KeyVersion.
        :type compartment_id: str

        :param id:
            The value to assign to the id property of this KeyVersion.
        :type id: str

        :param key_id:
            The value to assign to the key_id property of this KeyVersion.
        :type key_id: str

        :param public_key:
            The value to assign to the public_key property of this KeyVersion.
        :type public_key: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this KeyVersion.
            Allowed values for this property are: "CREATING", "ENABLING", "ENABLED", "DISABLING", "DISABLED", "DELETING", "DELETED", "PENDING_DELETION", "SCHEDULING_DELETION", "CANCELLING_DELETION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param origin:
            The value to assign to the origin property of this KeyVersion.
            Allowed values for this property are: "INTERNAL", "EXTERNAL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type origin: str

        :param time_created:
            The value to assign to the time_created property of this KeyVersion.
        :type time_created: datetime

        :param time_of_deletion:
            The value to assign to the time_of_deletion property of this KeyVersion.
        :type time_of_deletion: datetime

        :param vault_id:
            The value to assign to the vault_id property of this KeyVersion.
        :type vault_id: str

        :param restored_from_key_version_id:
            The value to assign to the restored_from_key_version_id property of this KeyVersion.
        :type restored_from_key_version_id: str

        :param replica_details:
            The value to assign to the replica_details property of this KeyVersion.
        :type replica_details: oci.key_management.models.KeyVersionReplicaDetails

        :param is_primary:
            The value to assign to the is_primary property of this KeyVersion.
        :type is_primary: bool

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'id': 'str',
            'key_id': 'str',
            'public_key': 'str',
            'lifecycle_state': 'str',
            'origin': 'str',
            'time_created': 'datetime',
            'time_of_deletion': 'datetime',
            'vault_id': 'str',
            'restored_from_key_version_id': 'str',
            'replica_details': 'KeyVersionReplicaDetails',
            'is_primary': 'bool'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'id': 'id',
            'key_id': 'keyId',
            'public_key': 'publicKey',
            'lifecycle_state': 'lifecycleState',
            'origin': 'origin',
            'time_created': 'timeCreated',
            'time_of_deletion': 'timeOfDeletion',
            'vault_id': 'vaultId',
            'restored_from_key_version_id': 'restoredFromKeyVersionId',
            'replica_details': 'replicaDetails',
            'is_primary': 'isPrimary'
        }

        self._compartment_id = None
        self._id = None
        self._key_id = None
        self._public_key = None
        self._lifecycle_state = None
        self._origin = None
        self._time_created = None
        self._time_of_deletion = None
        self._vault_id = None
        self._restored_from_key_version_id = None
        self._replica_details = None
        self._is_primary = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this KeyVersion.
        The OCID of the compartment that contains this key version.


        :return: The compartment_id of this KeyVersion.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this KeyVersion.
        The OCID of the compartment that contains this key version.


        :param compartment_id: The compartment_id of this KeyVersion.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def id(self):
        """
        **[Required]** Gets the id of this KeyVersion.
        The OCID of the key version.


        :return: The id of this KeyVersion.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this KeyVersion.
        The OCID of the key version.


        :param id: The id of this KeyVersion.
        :type: str
        """
        self._id = id

    @property
    def key_id(self):
        """
        **[Required]** Gets the key_id of this KeyVersion.
        The OCID of the key associated with this key version.


        :return: The key_id of this KeyVersion.
        :rtype: str
        """
        return self._key_id

    @key_id.setter
    def key_id(self, key_id):
        """
        Sets the key_id of this KeyVersion.
        The OCID of the key associated with this key version.


        :param key_id: The key_id of this KeyVersion.
        :type: str
        """
        self._key_id = key_id

    @property
    def public_key(self):
        """
        Gets the public_key of this KeyVersion.
        The public key in PEM format. (This value pertains only to RSA and ECDSA keys.)


        :return: The public_key of this KeyVersion.
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """
        Sets the public_key of this KeyVersion.
        The public key in PEM format. (This value pertains only to RSA and ECDSA keys.)


        :param public_key: The public_key of this KeyVersion.
        :type: str
        """
        self._public_key = public_key

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this KeyVersion.
        The key version's current lifecycle state.

        Example: `ENABLED`

        Allowed values for this property are: "CREATING", "ENABLING", "ENABLED", "DISABLING", "DISABLED", "DELETING", "DELETED", "PENDING_DELETION", "SCHEDULING_DELETION", "CANCELLING_DELETION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this KeyVersion.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this KeyVersion.
        The key version's current lifecycle state.

        Example: `ENABLED`


        :param lifecycle_state: The lifecycle_state of this KeyVersion.
        :type: str
        """
        allowed_values = ["CREATING", "ENABLING", "ENABLED", "DISABLING", "DISABLED", "DELETING", "DELETED", "PENDING_DELETION", "SCHEDULING_DELETION", "CANCELLING_DELETION"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def origin(self):
        """
        Gets the origin of this KeyVersion.
        The source of the key material. When this value is `INTERNAL`, Key Management
        created the key material. When this value is `EXTERNAL`, the key material
        was imported from an external source.

        Allowed values for this property are: "INTERNAL", "EXTERNAL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The origin of this KeyVersion.
        :rtype: str
        """
        return self._origin

    @origin.setter
    def origin(self, origin):
        """
        Sets the origin of this KeyVersion.
        The source of the key material. When this value is `INTERNAL`, Key Management
        created the key material. When this value is `EXTERNAL`, the key material
        was imported from an external source.


        :param origin: The origin of this KeyVersion.
        :type: str
        """
        allowed_values = ["INTERNAL", "EXTERNAL"]
        if not value_allowed_none_or_none_sentinel(origin, allowed_values):
            origin = 'UNKNOWN_ENUM_VALUE'
        self._origin = origin

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this KeyVersion.
        The date and time this key version was created, expressed in `RFC 3339`__ timestamp format.

        Example: \"2018-04-03T21:10:29.600Z\"

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this KeyVersion.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this KeyVersion.
        The date and time this key version was created, expressed in `RFC 3339`__ timestamp format.

        Example: \"2018-04-03T21:10:29.600Z\"

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this KeyVersion.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_of_deletion(self):
        """
        Gets the time_of_deletion of this KeyVersion.
        An optional property indicating when to delete the key version, expressed in `RFC 3339`__ timestamp format.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_of_deletion of this KeyVersion.
        :rtype: datetime
        """
        return self._time_of_deletion

    @time_of_deletion.setter
    def time_of_deletion(self, time_of_deletion):
        """
        Sets the time_of_deletion of this KeyVersion.
        An optional property indicating when to delete the key version, expressed in `RFC 3339`__ timestamp format.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_of_deletion: The time_of_deletion of this KeyVersion.
        :type: datetime
        """
        self._time_of_deletion = time_of_deletion

    @property
    def vault_id(self):
        """
        **[Required]** Gets the vault_id of this KeyVersion.
        The OCID of the vault that contains this key version.


        :return: The vault_id of this KeyVersion.
        :rtype: str
        """
        return self._vault_id

    @vault_id.setter
    def vault_id(self, vault_id):
        """
        Sets the vault_id of this KeyVersion.
        The OCID of the vault that contains this key version.


        :param vault_id: The vault_id of this KeyVersion.
        :type: str
        """
        self._vault_id = vault_id

    @property
    def restored_from_key_version_id(self):
        """
        Gets the restored_from_key_version_id of this KeyVersion.
        The OCID of the key version from which this key version was restored.


        :return: The restored_from_key_version_id of this KeyVersion.
        :rtype: str
        """
        return self._restored_from_key_version_id

    @restored_from_key_version_id.setter
    def restored_from_key_version_id(self, restored_from_key_version_id):
        """
        Sets the restored_from_key_version_id of this KeyVersion.
        The OCID of the key version from which this key version was restored.


        :param restored_from_key_version_id: The restored_from_key_version_id of this KeyVersion.
        :type: str
        """
        self._restored_from_key_version_id = restored_from_key_version_id

    @property
    def replica_details(self):
        """
        Gets the replica_details of this KeyVersion.

        :return: The replica_details of this KeyVersion.
        :rtype: oci.key_management.models.KeyVersionReplicaDetails
        """
        return self._replica_details

    @replica_details.setter
    def replica_details(self, replica_details):
        """
        Sets the replica_details of this KeyVersion.

        :param replica_details: The replica_details of this KeyVersion.
        :type: oci.key_management.models.KeyVersionReplicaDetails
        """
        self._replica_details = replica_details

    @property
    def is_primary(self):
        """
        Gets the is_primary of this KeyVersion.

        :return: The is_primary of this KeyVersion.
        :rtype: bool
        """
        return self._is_primary

    @is_primary.setter
    def is_primary(self, is_primary):
        """
        Sets the is_primary of this KeyVersion.

        :param is_primary: The is_primary of this KeyVersion.
        :type: bool
        """
        self._is_primary = is_primary

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ProblemTrendAggregation(object):
    """
    Provides the dimensions and their corresponding time and count.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ProblemTrendAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param dimensions_map:
            The value to assign to the dimensions_map property of this ProblemTrendAggregation.
        :type dimensions_map: dict(str, str)

        :param start_timestamp:
            The value to assign to the start_timestamp property of this ProblemTrendAggregation.
        :type start_timestamp: float

        :param duration_in_seconds:
            The value to assign to the duration_in_seconds property of this ProblemTrendAggregation.
        :type duration_in_seconds: int

        :param count:
            The value to assign to the count property of this ProblemTrendAggregation.
        :type count: int

        """
        self.swagger_types = {
            'dimensions_map': 'dict(str, str)',
            'start_timestamp': 'float',
            'duration_in_seconds': 'int',
            'count': 'int'
        }

        self.attribute_map = {
            'dimensions_map': 'dimensionsMap',
            'start_timestamp': 'startTimestamp',
            'duration_in_seconds': 'durationInSeconds',
            'count': 'count'
        }

        self._dimensions_map = None
        self._start_timestamp = None
        self._duration_in_seconds = None
        self._count = None

    @property
    def dimensions_map(self):
        """
        **[Required]** Gets the dimensions_map of this ProblemTrendAggregation.
        The key-value pairs of dimensions and their names.


        :return: The dimensions_map of this ProblemTrendAggregation.
        :rtype: dict(str, str)
        """
        return self._dimensions_map

    @dimensions_map.setter
    def dimensions_map(self, dimensions_map):
        """
        Sets the dimensions_map of this ProblemTrendAggregation.
        The key-value pairs of dimensions and their names.


        :param dimensions_map: The dimensions_map of this ProblemTrendAggregation.
        :type: dict(str, str)
        """
        self._dimensions_map = dimensions_map

    @property
    def start_timestamp(self):
        """
        **[Required]** Gets the start_timestamp of this ProblemTrendAggregation.
        Start Time in epoch seconds


        :return: The start_timestamp of this ProblemTrendAggregation.
        :rtype: float
        """
        return self._start_timestamp

    @start_timestamp.setter
    def start_timestamp(self, start_timestamp):
        """
        Sets the start_timestamp of this ProblemTrendAggregation.
        Start Time in epoch seconds


        :param start_timestamp: The start_timestamp of this ProblemTrendAggregation.
        :type: float
        """
        self._start_timestamp = start_timestamp

    @property
    def duration_in_seconds(self):
        """
        **[Required]** Gets the duration_in_seconds of this ProblemTrendAggregation.
        Duration


        :return: The duration_in_seconds of this ProblemTrendAggregation.
        :rtype: int
        """
        return self._duration_in_seconds

    @duration_in_seconds.setter
    def duration_in_seconds(self, duration_in_seconds):
        """
        Sets the duration_in_seconds of this ProblemTrendAggregation.
        Duration


        :param duration_in_seconds: The duration_in_seconds of this ProblemTrendAggregation.
        :type: int
        """
        self._duration_in_seconds = duration_in_seconds

    @property
    def count(self):
        """
        **[Required]** Gets the count of this ProblemTrendAggregation.
        The number of occurences with for the corresponding time range and dimensions.


        :return: The count of this ProblemTrendAggregation.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this ProblemTrendAggregation.
        The number of occurences with for the corresponding time range and dimensions.


        :param count: The count of this ProblemTrendAggregation.
        :type: int
        """
        self._count = count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Publication(object):
    """
    The model for an Oracle Cloud Infrastructure Marketplace publication.
    """

    #: A constant which can be used with the lifecycle_state property of a Publication.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Publication.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Publication.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Publication.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Publication.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the package_type property of a Publication.
    #: This constant has a value of "ORCHESTRATION"
    PACKAGE_TYPE_ORCHESTRATION = "ORCHESTRATION"

    #: A constant which can be used with the package_type property of a Publication.
    #: This constant has a value of "IMAGE"
    PACKAGE_TYPE_IMAGE = "IMAGE"

    #: A constant which can be used with the listing_type property of a Publication.
    #: This constant has a value of "COMMUNITY"
    LISTING_TYPE_COMMUNITY = "COMMUNITY"

    #: A constant which can be used with the listing_type property of a Publication.
    #: This constant has a value of "PARTNER"
    LISTING_TYPE_PARTNER = "PARTNER"

    #: A constant which can be used with the listing_type property of a Publication.
    #: This constant has a value of "PRIVATE"
    LISTING_TYPE_PRIVATE = "PRIVATE"

    def __init__(self, **kwargs):
        """
        Initializes a new Publication object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Publication.
            Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Publication.
        :type compartment_id: str

        :param id:
            The value to assign to the id property of this Publication.
        :type id: str

        :param name:
            The value to assign to the name property of this Publication.
        :type name: str

        :param short_description:
            The value to assign to the short_description property of this Publication.
        :type short_description: str

        :param long_description:
            The value to assign to the long_description property of this Publication.
        :type long_description: str

        :param support_contacts:
            The value to assign to the support_contacts property of this Publication.
        :type support_contacts: list[oci.marketplace.models.SupportContact]

        :param icon:
            The value to assign to the icon property of this Publication.
        :type icon: oci.marketplace.models.UploadData

        :param package_type:
            The value to assign to the package_type property of this Publication.
            Allowed values for this property are: "ORCHESTRATION", "IMAGE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type package_type: str

        :param listing_type:
            The value to assign to the listing_type property of this Publication.
            Allowed values for this property are: "COMMUNITY", "PARTNER", "PRIVATE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type listing_type: str

        :param supported_operating_systems:
            The value to assign to the supported_operating_systems property of this Publication.
        :type supported_operating_systems: list[oci.marketplace.models.OperatingSystem]

        :param time_created:
            The value to assign to the time_created property of this Publication.
        :type time_created: datetime

        :param defined_tags:
            The value to assign to the defined_tags property of this Publication.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Publication.
        :type freeform_tags: dict(str, str)

        """
        self.swagger_types = {
            'lifecycle_state': 'str',
            'compartment_id': 'str',
            'id': 'str',
            'name': 'str',
            'short_description': 'str',
            'long_description': 'str',
            'support_contacts': 'list[SupportContact]',
            'icon': 'UploadData',
            'package_type': 'str',
            'listing_type': 'str',
            'supported_operating_systems': 'list[OperatingSystem]',
            'time_created': 'datetime',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)'
        }

        self.attribute_map = {
            'lifecycle_state': 'lifecycleState',
            'compartment_id': 'compartmentId',
            'id': 'id',
            'name': 'name',
            'short_description': 'shortDescription',
            'long_description': 'longDescription',
            'support_contacts': 'supportContacts',
            'icon': 'icon',
            'package_type': 'packageType',
            'listing_type': 'listingType',
            'supported_operating_systems': 'supportedOperatingSystems',
            'time_created': 'timeCreated',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags'
        }

        self._lifecycle_state = None
        self._compartment_id = None
        self._id = None
        self._name = None
        self._short_description = None
        self._long_description = None
        self._support_contacts = None
        self._icon = None
        self._package_type = None
        self._listing_type = None
        self._supported_operating_systems = None
        self._time_created = None
        self._defined_tags = None
        self._freeform_tags = None

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Publication.
        The lifecycle state of the publication.

        Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Publication.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Publication.
        The lifecycle state of the publication.


        :param lifecycle_state: The lifecycle_state of this Publication.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Publication.
        The `OCID`__ of the compartment where the publication exists.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this Publication.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Publication.
        The `OCID`__ of the compartment where the publication exists.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this Publication.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Publication.
        The unique identifier for the publication in Marketplace.


        :return: The id of this Publication.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Publication.
        The unique identifier for the publication in Marketplace.


        :param id: The id of this Publication.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Publication.
        The name of the publication, which is also used in the listing.


        :return: The name of this Publication.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Publication.
        The name of the publication, which is also used in the listing.


        :param name: The name of this Publication.
        :type: str
        """
        self._name = name

    @property
    def short_description(self):
        """
        Gets the short_description of this Publication.
        A short description of the publication to use in the listing.


        :return: The short_description of this Publication.
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """
        Sets the short_description of this Publication.
        A short description of the publication to use in the listing.


        :param short_description: The short_description of this Publication.
        :type: str
        """
        self._short_description = short_description

    @property
    def long_description(self):
        """
        Gets the long_description of this Publication.
        A long description of the publication to use in the listing.


        :return: The long_description of this Publication.
        :rtype: str
        """
        return self._long_description

    @long_description.setter
    def long_description(self, long_description):
        """
        Sets the long_description of this Publication.
        A long description of the publication to use in the listing.


        :param long_description: The long_description of this Publication.
        :type: str
        """
        self._long_description = long_description

    @property
    def support_contacts(self):
        """
        Gets the support_contacts of this Publication.
        Contact information for getting support from the publisher for the listing.


        :return: The support_contacts of this Publication.
        :rtype: list[oci.marketplace.models.SupportContact]
        """
        return self._support_contacts

    @support_contacts.setter
    def support_contacts(self, support_contacts):
        """
        Sets the support_contacts of this Publication.
        Contact information for getting support from the publisher for the listing.


        :param support_contacts: The support_contacts of this Publication.
        :type: list[oci.marketplace.models.SupportContact]
        """
        self._support_contacts = support_contacts

    @property
    def icon(self):
        """
        Gets the icon of this Publication.

        :return: The icon of this Publication.
        :rtype: oci.marketplace.models.UploadData
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """
        Sets the icon of this Publication.

        :param icon: The icon of this Publication.
        :type: oci.marketplace.models.UploadData
        """
        self._icon = icon

    @property
    def package_type(self):
        """
        Gets the package_type of this Publication.
        The listing's package type.

        Allowed values for this property are: "ORCHESTRATION", "IMAGE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The package_type of this Publication.
        :rtype: str
        """
        return self._package_type

    @package_type.setter
    def package_type(self, package_type):
        """
        Sets the package_type of this Publication.
        The listing's package type.


        :param package_type: The package_type of this Publication.
        :type: str
        """
        allowed_values = ["ORCHESTRATION", "IMAGE"]
        if not value_allowed_none_or_none_sentinel(package_type, allowed_values):
            package_type = 'UNKNOWN_ENUM_VALUE'
        self._package_type = package_type

    @property
    def listing_type(self):
        """
        **[Required]** Gets the listing_type of this Publication.
        The publisher category to which the publication belongs. The publisher category informs where the listing appears for use.

        Allowed values for this property are: "COMMUNITY", "PARTNER", "PRIVATE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The listing_type of this Publication.
        :rtype: str
        """
        return self._listing_type

    @listing_type.setter
    def listing_type(self, listing_type):
        """
        Sets the listing_type of this Publication.
        The publisher category to which the publication belongs. The publisher category informs where the listing appears for use.


        :param listing_type: The listing_type of this Publication.
        :type: str
        """
        allowed_values = ["COMMUNITY", "PARTNER", "PRIVATE"]
        if not value_allowed_none_or_none_sentinel(listing_type, allowed_values):
            listing_type = 'UNKNOWN_ENUM_VALUE'
        self._listing_type = listing_type

    @property
    def supported_operating_systems(self):
        """
        Gets the supported_operating_systems of this Publication.
        The list of operating systems supprted by the listing.


        :return: The supported_operating_systems of this Publication.
        :rtype: list[oci.marketplace.models.OperatingSystem]
        """
        return self._supported_operating_systems

    @supported_operating_systems.setter
    def supported_operating_systems(self, supported_operating_systems):
        """
        Sets the supported_operating_systems of this Publication.
        The list of operating systems supprted by the listing.


        :param supported_operating_systems: The supported_operating_systems of this Publication.
        :type: list[oci.marketplace.models.OperatingSystem]
        """
        self._supported_operating_systems = supported_operating_systems

    @property
    def time_created(self):
        """
        Gets the time_created of this Publication.
        The date and time the publication was created, expressed in `RFC 3339`__
        timestamp format.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this Publication.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Publication.
        The date and time the publication was created, expressed in `RFC 3339`__
        timestamp format.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this Publication.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Publication.
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Publication.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Publication.
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Publication.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Publication.
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Publication.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Publication.
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Publication.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MonitorResultData(object):
    """
    Details of the monitor result data.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MonitorResultData object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this MonitorResultData.
        :type name: str

        :param byte_content:
            The value to assign to the byte_content property of this MonitorResultData.
        :type byte_content: str

        :param string_content:
            The value to assign to the string_content property of this MonitorResultData.
        :type string_content: str

        :param timestamp:
            The value to assign to the timestamp property of this MonitorResultData.
        :type timestamp: datetime

        """
        self.swagger_types = {
            'name': 'str',
            'byte_content': 'str',
            'string_content': 'str',
            'timestamp': 'datetime'
        }

        self.attribute_map = {
            'name': 'name',
            'byte_content': 'byteContent',
            'string_content': 'stringContent',
            'timestamp': 'timestamp'
        }

        self._name = None
        self._byte_content = None
        self._string_content = None
        self._timestamp = None

    @property
    def name(self):
        """
        Gets the name of this MonitorResultData.
        Name of the data.


        :return: The name of this MonitorResultData.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this MonitorResultData.
        Name of the data.


        :param name: The name of this MonitorResultData.
        :type: str
        """
        self._name = name

    @property
    def byte_content(self):
        """
        Gets the byte_content of this MonitorResultData.
        Data content in byte format.
        Example: Zip or Screenshot.


        :return: The byte_content of this MonitorResultData.
        :rtype: str
        """
        return self._byte_content

    @byte_content.setter
    def byte_content(self, byte_content):
        """
        Sets the byte_content of this MonitorResultData.
        Data content in byte format.
        Example: Zip or Screenshot.


        :param byte_content: The byte_content of this MonitorResultData.
        :type: str
        """
        self._byte_content = byte_content

    @property
    def string_content(self):
        """
        Gets the string_content of this MonitorResultData.
        Data content in string format.
        Example: HAR.


        :return: The string_content of this MonitorResultData.
        :rtype: str
        """
        return self._string_content

    @string_content.setter
    def string_content(self, string_content):
        """
        Sets the string_content of this MonitorResultData.
        Data content in string format.
        Example: HAR.


        :param string_content: The string_content of this MonitorResultData.
        :type: str
        """
        self._string_content = string_content

    @property
    def timestamp(self):
        """
        Gets the timestamp of this MonitorResultData.
        The time when the data was generated, expressed in `RFC 3339`__
        timestamp format.
        Example: `2020-02-13T22:47:12.613Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The timestamp of this MonitorResultData.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this MonitorResultData.
        The time when the data was generated, expressed in `RFC 3339`__
        timestamp format.
        Example: `2020-02-13T22:47:12.613Z`

        __ https://tools.ietf.org/html/rfc3339


        :param timestamp: The timestamp of this MonitorResultData.
        :type: datetime
        """
        self._timestamp = timestamp

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdatePrivateAccessChannelDetails(object):
    """
    Input payload to update a Private Access Channel.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdatePrivateAccessChannelDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdatePrivateAccessChannelDetails.
        :type display_name: str

        :param vcn_id:
            The value to assign to the vcn_id property of this UpdatePrivateAccessChannelDetails.
        :type vcn_id: str

        :param subnet_id:
            The value to assign to the subnet_id property of this UpdatePrivateAccessChannelDetails.
        :type subnet_id: str

        :param private_source_dns_zones:
            The value to assign to the private_source_dns_zones property of this UpdatePrivateAccessChannelDetails.
        :type private_source_dns_zones: list[oci.analytics.models.PrivateSourceDnsZone]

        """
        self.swagger_types = {
            'display_name': 'str',
            'vcn_id': 'str',
            'subnet_id': 'str',
            'private_source_dns_zones': 'list[PrivateSourceDnsZone]'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'vcn_id': 'vcnId',
            'subnet_id': 'subnetId',
            'private_source_dns_zones': 'privateSourceDnsZones'
        }

        self._display_name = None
        self._vcn_id = None
        self._subnet_id = None
        self._private_source_dns_zones = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdatePrivateAccessChannelDetails.
        Display Name of the Private Access Channel.


        :return: The display_name of this UpdatePrivateAccessChannelDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdatePrivateAccessChannelDetails.
        Display Name of the Private Access Channel.


        :param display_name: The display_name of this UpdatePrivateAccessChannelDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def vcn_id(self):
        """
        Gets the vcn_id of this UpdatePrivateAccessChannelDetails.
        OCID of the customer VCN peered with private access channel.


        :return: The vcn_id of this UpdatePrivateAccessChannelDetails.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this UpdatePrivateAccessChannelDetails.
        OCID of the customer VCN peered with private access channel.


        :param vcn_id: The vcn_id of this UpdatePrivateAccessChannelDetails.
        :type: str
        """
        self._vcn_id = vcn_id

    @property
    def subnet_id(self):
        """
        Gets the subnet_id of this UpdatePrivateAccessChannelDetails.
        OCID of the customer subnet connected to private access channel.


        :return: The subnet_id of this UpdatePrivateAccessChannelDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this UpdatePrivateAccessChannelDetails.
        OCID of the customer subnet connected to private access channel.


        :param subnet_id: The subnet_id of this UpdatePrivateAccessChannelDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def private_source_dns_zones(self):
        """
        Gets the private_source_dns_zones of this UpdatePrivateAccessChannelDetails.
        List of Private Source DNS zones registered with Private Access Channel,
        where datasource hostnames from these dns zones / domains will be resolved in the peered VCN for access from Analytics Instance.
        Min of 1 is required and Max of 30 Private Source DNS zones can be registered.


        :return: The private_source_dns_zones of this UpdatePrivateAccessChannelDetails.
        :rtype: list[oci.analytics.models.PrivateSourceDnsZone]
        """
        return self._private_source_dns_zones

    @private_source_dns_zones.setter
    def private_source_dns_zones(self, private_source_dns_zones):
        """
        Sets the private_source_dns_zones of this UpdatePrivateAccessChannelDetails.
        List of Private Source DNS zones registered with Private Access Channel,
        where datasource hostnames from these dns zones / domains will be resolved in the peered VCN for access from Analytics Instance.
        Min of 1 is required and Max of 30 Private Source DNS zones can be registered.


        :param private_source_dns_zones: The private_source_dns_zones of this UpdatePrivateAccessChannelDetails.
        :type: list[oci.analytics.models.PrivateSourceDnsZone]
        """
        self._private_source_dns_zones = private_source_dns_zones

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PutMessagesResult(object):
    """
    The response to a :func:`put_messages` request. It indicates the number
    of failed messages as well as an array of results for successful and failed messages.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PutMessagesResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param failures:
            The value to assign to the failures property of this PutMessagesResult.
        :type failures: int

        :param entries:
            The value to assign to the entries property of this PutMessagesResult.
        :type entries: list[oci.streaming.models.PutMessagesResultEntry]

        """
        self.swagger_types = {
            'failures': 'int',
            'entries': 'list[PutMessagesResultEntry]'
        }

        self.attribute_map = {
            'failures': 'failures',
            'entries': 'entries'
        }

        self._failures = None
        self._entries = None

    @property
    def failures(self):
        """
        **[Required]** Gets the failures of this PutMessagesResult.
        The number of messages that failed to be added to the stream.


        :return: The failures of this PutMessagesResult.
        :rtype: int
        """
        return self._failures

    @failures.setter
    def failures(self, failures):
        """
        Sets the failures of this PutMessagesResult.
        The number of messages that failed to be added to the stream.


        :param failures: The failures of this PutMessagesResult.
        :type: int
        """
        self._failures = failures

    @property
    def entries(self):
        """
        **[Required]** Gets the entries of this PutMessagesResult.
        An array of items representing the result of each message.
        The order is guaranteed to be the same as in the `PutMessagesDetails` object.
        If a message was successfully appended to the stream, the entry includes the `offset`, `partition`, and `timestamp`.
        If a message failed to be appended to the stream, the entry includes the `error` and `errorMessage`.


        :return: The entries of this PutMessagesResult.
        :rtype: list[oci.streaming.models.PutMessagesResultEntry]
        """
        return self._entries

    @entries.setter
    def entries(self, entries):
        """
        Sets the entries of this PutMessagesResult.
        An array of items representing the result of each message.
        The order is guaranteed to be the same as in the `PutMessagesDetails` object.
        If a message was successfully appended to the stream, the entry includes the `offset`, `partition`, and `timestamp`.
        If a message failed to be appended to the stream, the entry includes the `error` and `errorMessage`.


        :param entries: The entries of this PutMessagesResult.
        :type: list[oci.streaming.models.PutMessagesResultEntry]
        """
        self._entries = entries

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DeployEnvironmentSummary(object):
    """
    Summary of the deployment environment.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DeployEnvironmentSummary object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.devops.models.FunctionDeployEnvironmentSummary`
        * :class:`~oci.devops.models.ComputeInstanceGroupDeployEnvironmentSummary`
        * :class:`~oci.devops.models.OkeClusterDeployEnvironmentSummary`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DeployEnvironmentSummary.
        :type id: str

        :param description:
            The value to assign to the description property of this DeployEnvironmentSummary.
        :type description: str

        :param display_name:
            The value to assign to the display_name property of this DeployEnvironmentSummary.
        :type display_name: str

        :param project_id:
            The value to assign to the project_id property of this DeployEnvironmentSummary.
        :type project_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DeployEnvironmentSummary.
        :type compartment_id: str

        :param deploy_environment_type:
            The value to assign to the deploy_environment_type property of this DeployEnvironmentSummary.
        :type deploy_environment_type: str

        :param time_created:
            The value to assign to the time_created property of this DeployEnvironmentSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this DeployEnvironmentSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DeployEnvironmentSummary.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this DeployEnvironmentSummary.
        :type lifecycle_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DeployEnvironmentSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DeployEnvironmentSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this DeployEnvironmentSummary.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'description': 'str',
            'display_name': 'str',
            'project_id': 'str',
            'compartment_id': 'str',
            'deploy_environment_type': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'description': 'description',
            'display_name': 'displayName',
            'project_id': 'projectId',
            'compartment_id': 'compartmentId',
            'deploy_environment_type': 'deployEnvironmentType',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._description = None
        self._display_name = None
        self._project_id = None
        self._compartment_id = None
        self._deploy_environment_type = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['deployEnvironmentType']

        if type == 'FUNCTION':
            return 'FunctionDeployEnvironmentSummary'

        if type == 'COMPUTE_INSTANCE_GROUP':
            return 'ComputeInstanceGroupDeployEnvironmentSummary'

        if type == 'OKE_CLUSTER':
            return 'OkeClusterDeployEnvironmentSummary'
        else:
            return 'DeployEnvironmentSummary'

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DeployEnvironmentSummary.
        Unique identifier that is immutable on creation.


        :return: The id of this DeployEnvironmentSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DeployEnvironmentSummary.
        Unique identifier that is immutable on creation.


        :param id: The id of this DeployEnvironmentSummary.
        :type: str
        """
        self._id = id

    @property
    def description(self):
        """
        Gets the description of this DeployEnvironmentSummary.
        Optional description about the deployment environment.


        :return: The description of this DeployEnvironmentSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DeployEnvironmentSummary.
        Optional description about the deployment environment.


        :param description: The description of this DeployEnvironmentSummary.
        :type: str
        """
        self._description = description

    @property
    def display_name(self):
        """
        Gets the display_name of this DeployEnvironmentSummary.
        Deployment environment display name, which can be renamed and is not necessarily unique.


        :return: The display_name of this DeployEnvironmentSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DeployEnvironmentSummary.
        Deployment environment display name, which can be renamed and is not necessarily unique.


        :param display_name: The display_name of this DeployEnvironmentSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def project_id(self):
        """
        **[Required]** Gets the project_id of this DeployEnvironmentSummary.
        The OCID of a project.


        :return: The project_id of this DeployEnvironmentSummary.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """
        Sets the project_id of this DeployEnvironmentSummary.
        The OCID of a project.


        :param project_id: The project_id of this DeployEnvironmentSummary.
        :type: str
        """
        self._project_id = project_id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this DeployEnvironmentSummary.
        The OCID of a compartment.


        :return: The compartment_id of this DeployEnvironmentSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DeployEnvironmentSummary.
        The OCID of a compartment.


        :param compartment_id: The compartment_id of this DeployEnvironmentSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def deploy_environment_type(self):
        """
        **[Required]** Gets the deploy_environment_type of this DeployEnvironmentSummary.
        Deployment environment type.


        :return: The deploy_environment_type of this DeployEnvironmentSummary.
        :rtype: str
        """
        return self._deploy_environment_type

    @deploy_environment_type.setter
    def deploy_environment_type(self, deploy_environment_type):
        """
        Sets the deploy_environment_type of this DeployEnvironmentSummary.
        Deployment environment type.


        :param deploy_environment_type: The deploy_environment_type of this DeployEnvironmentSummary.
        :type: str
        """
        self._deploy_environment_type = deploy_environment_type

    @property
    def time_created(self):
        """
        Gets the time_created of this DeployEnvironmentSummary.
        Time the deployment environment was created. Format defined by `RFC3339`__.

        __ https://datatracker.ietf.org/doc/html/rfc3339


        :return: The time_created of this DeployEnvironmentSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DeployEnvironmentSummary.
        Time the deployment environment was created. Format defined by `RFC3339`__.

        __ https://datatracker.ietf.org/doc/html/rfc3339


        :param time_created: The time_created of this DeployEnvironmentSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this DeployEnvironmentSummary.
        Time the deployment environment was updated. Format defined by `RFC3339`__.

        __ https://datatracker.ietf.org/doc/html/rfc3339


        :return: The time_updated of this DeployEnvironmentSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this DeployEnvironmentSummary.
        Time the deployment environment was updated. Format defined by `RFC3339`__.

        __ https://datatracker.ietf.org/doc/html/rfc3339


        :param time_updated: The time_updated of this DeployEnvironmentSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this DeployEnvironmentSummary.
        The current state of the deployment environment.


        :return: The lifecycle_state of this DeployEnvironmentSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DeployEnvironmentSummary.
        The current state of the deployment environment.


        :param lifecycle_state: The lifecycle_state of this DeployEnvironmentSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this DeployEnvironmentSummary.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :return: The lifecycle_details of this DeployEnvironmentSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this DeployEnvironmentSummary.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :param lifecycle_details: The lifecycle_details of this DeployEnvironmentSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DeployEnvironmentSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See `Resource Tags`__. Example: `{\"bar-key\": \"value\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this DeployEnvironmentSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DeployEnvironmentSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See `Resource Tags`__. Example: `{\"bar-key\": \"value\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this DeployEnvironmentSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DeployEnvironmentSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__. Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this DeployEnvironmentSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DeployEnvironmentSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__. Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this DeployEnvironmentSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this DeployEnvironmentSummary.
        Usage of system tag keys. These predefined keys are scoped to namespaces. See `Resource Tags`__. Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The system_tags of this DeployEnvironmentSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this DeployEnvironmentSummary.
        Usage of system tag keys. These predefined keys are scoped to namespaces. See `Resource Tags`__. Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param system_tags: The system_tags of this DeployEnvironmentSummary.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AccessRuleCriteria(object):
    """
    When defined, the parent challenge would be applied only for the requests that matched all the listed conditions.
    """

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "URL_IS"
    CONDITION_URL_IS = "URL_IS"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "URL_IS_NOT"
    CONDITION_URL_IS_NOT = "URL_IS_NOT"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "URL_STARTS_WITH"
    CONDITION_URL_STARTS_WITH = "URL_STARTS_WITH"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "URL_PART_ENDS_WITH"
    CONDITION_URL_PART_ENDS_WITH = "URL_PART_ENDS_WITH"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "URL_PART_CONTAINS"
    CONDITION_URL_PART_CONTAINS = "URL_PART_CONTAINS"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "URL_REGEX"
    CONDITION_URL_REGEX = "URL_REGEX"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "URL_DOES_NOT_MATCH_REGEX"
    CONDITION_URL_DOES_NOT_MATCH_REGEX = "URL_DOES_NOT_MATCH_REGEX"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "URL_DOES_NOT_START_WITH"
    CONDITION_URL_DOES_NOT_START_WITH = "URL_DOES_NOT_START_WITH"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "URL_PART_DOES_NOT_CONTAIN"
    CONDITION_URL_PART_DOES_NOT_CONTAIN = "URL_PART_DOES_NOT_CONTAIN"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "URL_PART_DOES_NOT_END_WITH"
    CONDITION_URL_PART_DOES_NOT_END_WITH = "URL_PART_DOES_NOT_END_WITH"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "IP_IS"
    CONDITION_IP_IS = "IP_IS"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "IP_IS_NOT"
    CONDITION_IP_IS_NOT = "IP_IS_NOT"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "IP_IN_LIST"
    CONDITION_IP_IN_LIST = "IP_IN_LIST"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "IP_NOT_IN_LIST"
    CONDITION_IP_NOT_IN_LIST = "IP_NOT_IN_LIST"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "HTTP_HEADER_CONTAINS"
    CONDITION_HTTP_HEADER_CONTAINS = "HTTP_HEADER_CONTAINS"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "HTTP_METHOD_IS"
    CONDITION_HTTP_METHOD_IS = "HTTP_METHOD_IS"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "HTTP_METHOD_IS_NOT"
    CONDITION_HTTP_METHOD_IS_NOT = "HTTP_METHOD_IS_NOT"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "COUNTRY_IS"
    CONDITION_COUNTRY_IS = "COUNTRY_IS"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "COUNTRY_IS_NOT"
    CONDITION_COUNTRY_IS_NOT = "COUNTRY_IS_NOT"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "USER_AGENT_IS"
    CONDITION_USER_AGENT_IS = "USER_AGENT_IS"

    #: A constant which can be used with the condition property of a AccessRuleCriteria.
    #: This constant has a value of "USER_AGENT_IS_NOT"
    CONDITION_USER_AGENT_IS_NOT = "USER_AGENT_IS_NOT"

    def __init__(self, **kwargs):
        """
        Initializes a new AccessRuleCriteria object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param condition:
            The value to assign to the condition property of this AccessRuleCriteria.
            Allowed values for this property are: "URL_IS", "URL_IS_NOT", "URL_STARTS_WITH", "URL_PART_ENDS_WITH", "URL_PART_CONTAINS", "URL_REGEX", "URL_DOES_NOT_MATCH_REGEX", "URL_DOES_NOT_START_WITH", "URL_PART_DOES_NOT_CONTAIN", "URL_PART_DOES_NOT_END_WITH", "IP_IS", "IP_IS_NOT", "IP_IN_LIST", "IP_NOT_IN_LIST", "HTTP_HEADER_CONTAINS", "HTTP_METHOD_IS", "HTTP_METHOD_IS_NOT", "COUNTRY_IS", "COUNTRY_IS_NOT", "USER_AGENT_IS", "USER_AGENT_IS_NOT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type condition: str

        :param value:
            The value to assign to the value property of this AccessRuleCriteria.
        :type value: str

        :param is_case_sensitive:
            The value to assign to the is_case_sensitive property of this AccessRuleCriteria.
        :type is_case_sensitive: bool

        """
        self.swagger_types = {
            'condition': 'str',
            'value': 'str',
            'is_case_sensitive': 'bool'
        }

        self.attribute_map = {
            'condition': 'condition',
            'value': 'value',
            'is_case_sensitive': 'isCaseSensitive'
        }

        self._condition = None
        self._value = None
        self._is_case_sensitive = None

    @property
    def condition(self):
        """
        **[Required]** Gets the condition of this AccessRuleCriteria.
        The criteria the access rule and JavaScript Challenge uses to determine if action should be taken on a request.
        - **URL_IS:** Matches if the concatenation of request URL path and query is identical to the contents of the `value` field. URL must start with a `/`.
        - **URL_IS_NOT:** Matches if the concatenation of request URL path and query is not identical to the contents of the `value` field. URL must start with a `/`.
        - **URL_STARTS_WITH:** Matches if the concatenation of request URL path and query starts with the contents of the `value` field. URL must start with a `/`.
        - **URL_PART_ENDS_WITH:** Matches if the concatenation of request URL path and query ends with the contents of the `value` field.
        - **URL_PART_CONTAINS:** Matches if the concatenation of request URL path and query contains the contents of the `value` field.
        - **URL_REGEX:** Matches if the concatenation of request URL path and query is described by the regular expression in the value field. The value must be a valid regular expression recognized by the PCRE library in Nginx (https://www.pcre.org).
        - **URL_DOES_NOT_MATCH_REGEX:** Matches if the concatenation of request URL path and query is not described by the regular expression in the `value` field. The value must be a valid regular expression recognized by the PCRE library in Nginx (https://www.pcre.org).
        - **URL_DOES_NOT_START_WITH:** Matches if the concatenation of request URL path and query does not start with the contents of the `value` field.
        - **URL_PART_DOES_NOT_CONTAIN:** Matches if the concatenation of request URL path and query does not contain the contents of the `value` field.
        - **URL_PART_DOES_NOT_END_WITH:** Matches if the concatenation of request URL path and query does not end with the contents of the `value` field.
        - **IP_IS:** Matches if the request originates from one of the IP addresses contained in the defined address list. The `value` in this case is string with one or multiple IPs or CIDR notations separated by new line symbol \

        *Example:* \"1.1.1.1\
        1.1.1.2\
        1.2.2.1/30\"
        - **IP_IS_NOT:** Matches if the request does not originate from any of the IP addresses contained in the defined address list. The `value` in this case is string with one or multiple IPs or CIDR notations separated by new line symbol \

        *Example:* \"1.1.1.1\
        1.1.1.2\
        1.2.2.1/30\"
        - **IP_IN_LIST:** Matches if the request originates from one of the IP addresses contained in the referenced address list. The `value` in this case is OCID of the address list.
        - **IP_NOT_IN_LIST:** Matches if the request does not originate from any IP address contained in the referenced address list. The `value` field in this case is OCID of the address list.
        - **HTTP_HEADER_CONTAINS:** The HTTP_HEADER_CONTAINS criteria is defined using a compound value separated by a colon: a header field name and a header field value. `host:test.example.com` is an example of a criteria value where `host` is the header field name and `test.example.com` is the header field value. A request matches when the header field name is a case insensitive match and the header field value is a case insensitive, substring match.
        *Example:* With a criteria value of `host:test.example.com`, where `host` is the name of the field and `test.example.com` is the value of the host field, a request with the header values, `Host: www.test.example.com` will match, where as a request with header values of `host: www.example.com` or `host: test.sub.example.com` will not match.
        - **HTTP_METHOD_IS:** Matches if the request method is identical to one of the values listed in field. The `value` in this case is string with one or multiple HTTP methods separated by new line symbol \
         The list of available methods: `GET`, `HEAD`, `POST`, `PUT`, `DELETE`, `CONNECT`, `OPTIONS`, `TRACE`, `PATCH`

         *Example:* \"GET\
        POST\"

        - **HTTP_METHOD_IS_NOT:** Matches if the request is not identical to any of the contents of the `value` field. The `value` in this case is string with one or multiple HTTP methods separated by new line symbol \
         The list of available methods: `GET`, `HEAD`, `POST`, `PUT`, `DELETE`, `CONNECT`, `OPTIONS`, `TRACE`, `PATCH`

         *Example:* \"GET\
        POST\"

        - **COUNTRY_IS:** Matches if the request originates from one of countries in the `value` field. The `value` in this case is string with one or multiple countries separated by new line symbol \
         Country codes are in ISO 3166-1 alpha-2 format. For a list of codes, see `ISO's website`__.
        *Example:* \"AL\
        DZ\
        AM\"
        - **COUNTRY_IS_NOT:** Matches if the request does not originate from any of countries in the `value` field. The `value` in this case is string with one or multiple countries separated by new line symbol \
         Country codes are in ISO 3166-1 alpha-2 format. For a list of codes, see `ISO's website`__.
        *Example:* \"AL\
        DZ\
        AM\"
        - **USER_AGENT_IS:** Matches if the requesting user agent is identical to the contents of the `value` field.
        *Example:* `Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:35.0) Gecko/20100101 Firefox/35.0`
        - **USER_AGENT_IS_NOT:** Matches if the requesting user agent is not identical to the contents of the `value` field.
        *Example:* `Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:35.0) Gecko/20100101 Firefox/35.0`

        __ https://www.iso.org/obp/ui/#search/code/
        __ https://www.iso.org/obp/ui/#search/code/

        Allowed values for this property are: "URL_IS", "URL_IS_NOT", "URL_STARTS_WITH", "URL_PART_ENDS_WITH", "URL_PART_CONTAINS", "URL_REGEX", "URL_DOES_NOT_MATCH_REGEX", "URL_DOES_NOT_START_WITH", "URL_PART_DOES_NOT_CONTAIN", "URL_PART_DOES_NOT_END_WITH", "IP_IS", "IP_IS_NOT", "IP_IN_LIST", "IP_NOT_IN_LIST", "HTTP_HEADER_CONTAINS", "HTTP_METHOD_IS", "HTTP_METHOD_IS_NOT", "COUNTRY_IS", "COUNTRY_IS_NOT", "USER_AGENT_IS", "USER_AGENT_IS_NOT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The condition of this AccessRuleCriteria.
        :rtype: str
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """
        Sets the condition of this AccessRuleCriteria.
        The criteria the access rule and JavaScript Challenge uses to determine if action should be taken on a request.
        - **URL_IS:** Matches if the concatenation of request URL path and query is identical to the contents of the `value` field. URL must start with a `/`.
        - **URL_IS_NOT:** Matches if the concatenation of request URL path and query is not identical to the contents of the `value` field. URL must start with a `/`.
        - **URL_STARTS_WITH:** Matches if the concatenation of request URL path and query starts with the contents of the `value` field. URL must start with a `/`.
        - **URL_PART_ENDS_WITH:** Matches if the concatenation of request URL path and query ends with the contents of the `value` field.
        - **URL_PART_CONTAINS:** Matches if the concatenation of request URL path and query contains the contents of the `value` field.
        - **URL_REGEX:** Matches if the concatenation of request URL path and query is described by the regular expression in the value field. The value must be a valid regular expression recognized by the PCRE library in Nginx (https://www.pcre.org).
        - **URL_DOES_NOT_MATCH_REGEX:** Matches if the concatenation of request URL path and query is not described by the regular expression in the `value` field. The value must be a valid regular expression recognized by the PCRE library in Nginx (https://www.pcre.org).
        - **URL_DOES_NOT_START_WITH:** Matches if the concatenation of request URL path and query does not start with the contents of the `value` field.
        - **URL_PART_DOES_NOT_CONTAIN:** Matches if the concatenation of request URL path and query does not contain the contents of the `value` field.
        - **URL_PART_DOES_NOT_END_WITH:** Matches if the concatenation of request URL path and query does not end with the contents of the `value` field.
        - **IP_IS:** Matches if the request originates from one of the IP addresses contained in the defined address list. The `value` in this case is string with one or multiple IPs or CIDR notations separated by new line symbol \

        *Example:* \"1.1.1.1\
        1.1.1.2\
        1.2.2.1/30\"
        - **IP_IS_NOT:** Matches if the request does not originate from any of the IP addresses contained in the defined address list. The `value` in this case is string with one or multiple IPs or CIDR notations separated by new line symbol \

        *Example:* \"1.1.1.1\
        1.1.1.2\
        1.2.2.1/30\"
        - **IP_IN_LIST:** Matches if the request originates from one of the IP addresses contained in the referenced address list. The `value` in this case is OCID of the address list.
        - **IP_NOT_IN_LIST:** Matches if the request does not originate from any IP address contained in the referenced address list. The `value` field in this case is OCID of the address list.
        - **HTTP_HEADER_CONTAINS:** The HTTP_HEADER_CONTAINS criteria is defined using a compound value separated by a colon: a header field name and a header field value. `host:test.example.com` is an example of a criteria value where `host` is the header field name and `test.example.com` is the header field value. A request matches when the header field name is a case insensitive match and the header field value is a case insensitive, substring match.
        *Example:* With a criteria value of `host:test.example.com`, where `host` is the name of the field and `test.example.com` is the value of the host field, a request with the header values, `Host: www.test.example.com` will match, where as a request with header values of `host: www.example.com` or `host: test.sub.example.com` will not match.
        - **HTTP_METHOD_IS:** Matches if the request method is identical to one of the values listed in field. The `value` in this case is string with one or multiple HTTP methods separated by new line symbol \
         The list of available methods: `GET`, `HEAD`, `POST`, `PUT`, `DELETE`, `CONNECT`, `OPTIONS`, `TRACE`, `PATCH`

         *Example:* \"GET\
        POST\"

        - **HTTP_METHOD_IS_NOT:** Matches if the request is not identical to any of the contents of the `value` field. The `value` in this case is string with one or multiple HTTP methods separated by new line symbol \
         The list of available methods: `GET`, `HEAD`, `POST`, `PUT`, `DELETE`, `CONNECT`, `OPTIONS`, `TRACE`, `PATCH`

         *Example:* \"GET\
        POST\"

        - **COUNTRY_IS:** Matches if the request originates from one of countries in the `value` field. The `value` in this case is string with one or multiple countries separated by new line symbol \
         Country codes are in ISO 3166-1 alpha-2 format. For a list of codes, see `ISO's website`__.
        *Example:* \"AL\
        DZ\
        AM\"
        - **COUNTRY_IS_NOT:** Matches if the request does not originate from any of countries in the `value` field. The `value` in this case is string with one or multiple countries separated by new line symbol \
         Country codes are in ISO 3166-1 alpha-2 format. For a list of codes, see `ISO's website`__.
        *Example:* \"AL\
        DZ\
        AM\"
        - **USER_AGENT_IS:** Matches if the requesting user agent is identical to the contents of the `value` field.
        *Example:* `Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:35.0) Gecko/20100101 Firefox/35.0`
        - **USER_AGENT_IS_NOT:** Matches if the requesting user agent is not identical to the contents of the `value` field.
        *Example:* `Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:35.0) Gecko/20100101 Firefox/35.0`

        __ https://www.iso.org/obp/ui/#search/code/
        __ https://www.iso.org/obp/ui/#search/code/


        :param condition: The condition of this AccessRuleCriteria.
        :type: str
        """
        allowed_values = ["URL_IS", "URL_IS_NOT", "URL_STARTS_WITH", "URL_PART_ENDS_WITH", "URL_PART_CONTAINS", "URL_REGEX", "URL_DOES_NOT_MATCH_REGEX", "URL_DOES_NOT_START_WITH", "URL_PART_DOES_NOT_CONTAIN", "URL_PART_DOES_NOT_END_WITH", "IP_IS", "IP_IS_NOT", "IP_IN_LIST", "IP_NOT_IN_LIST", "HTTP_HEADER_CONTAINS", "HTTP_METHOD_IS", "HTTP_METHOD_IS_NOT", "COUNTRY_IS", "COUNTRY_IS_NOT", "USER_AGENT_IS", "USER_AGENT_IS_NOT"]
        if not value_allowed_none_or_none_sentinel(condition, allowed_values):
            condition = 'UNKNOWN_ENUM_VALUE'
        self._condition = condition

    @property
    def value(self):
        """
        **[Required]** Gets the value of this AccessRuleCriteria.
        The criteria value.


        :return: The value of this AccessRuleCriteria.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this AccessRuleCriteria.
        The criteria value.


        :param value: The value of this AccessRuleCriteria.
        :type: str
        """
        self._value = value

    @property
    def is_case_sensitive(self):
        """
        Gets the is_case_sensitive of this AccessRuleCriteria.
        When enabled, the condition will be matched with case-sensitive rules.


        :return: The is_case_sensitive of this AccessRuleCriteria.
        :rtype: bool
        """
        return self._is_case_sensitive

    @is_case_sensitive.setter
    def is_case_sensitive(self, is_case_sensitive):
        """
        Sets the is_case_sensitive of this AccessRuleCriteria.
        When enabled, the condition will be matched with case-sensitive rules.


        :param is_case_sensitive: The is_case_sensitive of this AccessRuleCriteria.
        :type: bool
        """
        self._is_case_sensitive = is_case_sensitive

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Storage(object):
    """
    This is the storage configuration and status of a tenancy in Logan Analytics application
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Storage object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_archiving_enabled:
            The value to assign to the is_archiving_enabled property of this Storage.
        :type is_archiving_enabled: bool

        :param archiving_configuration:
            The value to assign to the archiving_configuration property of this Storage.
        :type archiving_configuration: oci.log_analytics.models.ArchivingConfiguration

        """
        self.swagger_types = {
            'is_archiving_enabled': 'bool',
            'archiving_configuration': 'ArchivingConfiguration'
        }

        self.attribute_map = {
            'is_archiving_enabled': 'isArchivingEnabled',
            'archiving_configuration': 'archivingConfiguration'
        }

        self._is_archiving_enabled = None
        self._archiving_configuration = None

    @property
    def is_archiving_enabled(self):
        """
        **[Required]** Gets the is_archiving_enabled of this Storage.
        This indicates if old data can be archived for a tenancy


        :return: The is_archiving_enabled of this Storage.
        :rtype: bool
        """
        return self._is_archiving_enabled

    @is_archiving_enabled.setter
    def is_archiving_enabled(self, is_archiving_enabled):
        """
        Sets the is_archiving_enabled of this Storage.
        This indicates if old data can be archived for a tenancy


        :param is_archiving_enabled: The is_archiving_enabled of this Storage.
        :type: bool
        """
        self._is_archiving_enabled = is_archiving_enabled

    @property
    def archiving_configuration(self):
        """
        **[Required]** Gets the archiving_configuration of this Storage.

        :return: The archiving_configuration of this Storage.
        :rtype: oci.log_analytics.models.ArchivingConfiguration
        """
        return self._archiving_configuration

    @archiving_configuration.setter
    def archiving_configuration(self, archiving_configuration):
        """
        Sets the archiving_configuration of this Storage.

        :param archiving_configuration: The archiving_configuration of this Storage.
        :type: oci.log_analytics.models.ArchivingConfiguration
        """
        self._archiving_configuration = archiving_configuration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateServiceGatewayDetails(object):
    """
    UpdateServiceGatewayDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateServiceGatewayDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param block_traffic:
            The value to assign to the block_traffic property of this UpdateServiceGatewayDetails.
        :type block_traffic: bool

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateServiceGatewayDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this UpdateServiceGatewayDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateServiceGatewayDetails.
        :type freeform_tags: dict(str, str)

        :param route_table_id:
            The value to assign to the route_table_id property of this UpdateServiceGatewayDetails.
        :type route_table_id: str

        :param services:
            The value to assign to the services property of this UpdateServiceGatewayDetails.
        :type services: list[oci.core.models.ServiceIdRequestDetails]

        """
        self.swagger_types = {
            'block_traffic': 'bool',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'route_table_id': 'str',
            'services': 'list[ServiceIdRequestDetails]'
        }

        self.attribute_map = {
            'block_traffic': 'blockTraffic',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'route_table_id': 'routeTableId',
            'services': 'services'
        }

        self._block_traffic = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._route_table_id = None
        self._services = None

    @property
    def block_traffic(self):
        """
        Gets the block_traffic of this UpdateServiceGatewayDetails.
        Whether the service gateway blocks all traffic through it. The default is `false`. When
        this is `true`, traffic is not routed to any services, regardless of route rules.

        Example: `true`


        :return: The block_traffic of this UpdateServiceGatewayDetails.
        :rtype: bool
        """
        return self._block_traffic

    @block_traffic.setter
    def block_traffic(self, block_traffic):
        """
        Sets the block_traffic of this UpdateServiceGatewayDetails.
        Whether the service gateway blocks all traffic through it. The default is `false`. When
        this is `true`, traffic is not routed to any services, regardless of route rules.

        Example: `true`


        :param block_traffic: The block_traffic of this UpdateServiceGatewayDetails.
        :type: bool
        """
        self._block_traffic = block_traffic

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateServiceGatewayDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateServiceGatewayDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateServiceGatewayDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateServiceGatewayDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateServiceGatewayDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this UpdateServiceGatewayDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateServiceGatewayDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this UpdateServiceGatewayDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateServiceGatewayDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateServiceGatewayDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateServiceGatewayDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateServiceGatewayDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def route_table_id(self):
        """
        Gets the route_table_id of this UpdateServiceGatewayDetails.
        The OCID of the route table the service gateway will use.
        For information about why you would associate a route table with a service gateway, see
        `Transit Routing: Private Access to Oracle Services`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitroutingoracleservices.htm


        :return: The route_table_id of this UpdateServiceGatewayDetails.
        :rtype: str
        """
        return self._route_table_id

    @route_table_id.setter
    def route_table_id(self, route_table_id):
        """
        Sets the route_table_id of this UpdateServiceGatewayDetails.
        The OCID of the route table the service gateway will use.
        For information about why you would associate a route table with a service gateway, see
        `Transit Routing: Private Access to Oracle Services`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitroutingoracleservices.htm


        :param route_table_id: The route_table_id of this UpdateServiceGatewayDetails.
        :type: str
        """
        self._route_table_id = route_table_id

    @property
    def services(self):
        """
        Gets the services of this UpdateServiceGatewayDetails.
        List of all the `Service` objects you want enabled on this service gateway. Sending an empty list
        means you want to disable all services. Omitting this parameter entirely keeps the
        existing list of services intact.

        You can also enable or disable a particular `Service` by using
        :func:`attach_service_id` or
        :func:`detach_service_id`.

        For each enabled `Service`, make sure there's a route rule with the `Service` object's `cidrBlock`
        as the rule's destination and the service gateway as the rule's target. See
        :class:`RouteTable`.


        :return: The services of this UpdateServiceGatewayDetails.
        :rtype: list[oci.core.models.ServiceIdRequestDetails]
        """
        return self._services

    @services.setter
    def services(self, services):
        """
        Sets the services of this UpdateServiceGatewayDetails.
        List of all the `Service` objects you want enabled on this service gateway. Sending an empty list
        means you want to disable all services. Omitting this parameter entirely keeps the
        existing list of services intact.

        You can also enable or disable a particular `Service` by using
        :func:`attach_service_id` or
        :func:`detach_service_id`.

        For each enabled `Service`, make sure there's a route rule with the `Service` object's `cidrBlock`
        as the rule's destination and the service gateway as the rule's target. See
        :class:`RouteTable`.


        :param services: The services of this UpdateServiceGatewayDetails.
        :type: list[oci.core.models.ServiceIdRequestDetails]
        """
        self._services = services

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .source_details import SourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ImportSourceDetails(SourceDetails):
    """
    / Basic details about the source, import manifest and object storage bucket as well as object name of the archive that should be used during import
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ImportSourceDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.application_migration.models.ImportSourceDetails.type` attribute
        of this class is ``IMPORT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this ImportSourceDetails.
            Allowed values for this property are: "OCIC", "INTERNAL_COMPUTE", "OCC", "OCIC_IDCS", "IMPORT"
        :type type: str

        :param manifest:
            The value to assign to the manifest property of this ImportSourceDetails.
        :type manifest: oci.application_migration.models.ImportManifest

        :param namespace:
            The value to assign to the namespace property of this ImportSourceDetails.
        :type namespace: str

        :param bucket:
            The value to assign to the bucket property of this ImportSourceDetails.
        :type bucket: str

        :param object_name:
            The value to assign to the object_name property of this ImportSourceDetails.
        :type object_name: str

        """
        self.swagger_types = {
            'type': 'str',
            'manifest': 'ImportManifest',
            'namespace': 'str',
            'bucket': 'str',
            'object_name': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'manifest': 'manifest',
            'namespace': 'namespace',
            'bucket': 'bucket',
            'object_name': 'objectName'
        }

        self._type = None
        self._manifest = None
        self._namespace = None
        self._bucket = None
        self._object_name = None
        self._type = 'IMPORT'

    @property
    def manifest(self):
        """
        **[Required]** Gets the manifest of this ImportSourceDetails.

        :return: The manifest of this ImportSourceDetails.
        :rtype: oci.application_migration.models.ImportManifest
        """
        return self._manifest

    @manifest.setter
    def manifest(self, manifest):
        """
        Sets the manifest of this ImportSourceDetails.

        :param manifest: The manifest of this ImportSourceDetails.
        :type: oci.application_migration.models.ImportManifest
        """
        self._manifest = manifest

    @property
    def namespace(self):
        """
        **[Required]** Gets the namespace of this ImportSourceDetails.
        the object storage namespace where the bucket and uploaded object resides


        :return: The namespace of this ImportSourceDetails.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this ImportSourceDetails.
        the object storage namespace where the bucket and uploaded object resides


        :param namespace: The namespace of this ImportSourceDetails.
        :type: str
        """
        self._namespace = namespace

    @property
    def bucket(self):
        """
        **[Required]** Gets the bucket of this ImportSourceDetails.
        the bucket wherein the export archive exists in object storage


        :return: The bucket of this ImportSourceDetails.
        :rtype: str
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """
        Sets the bucket of this ImportSourceDetails.
        the bucket wherein the export archive exists in object storage


        :param bucket: The bucket of this ImportSourceDetails.
        :type: str
        """
        self._bucket = bucket

    @property
    def object_name(self):
        """
        **[Required]** Gets the object_name of this ImportSourceDetails.
        the name of the archive as it exists in object storage


        :return: The object_name of this ImportSourceDetails.
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """
        Sets the object_name of this ImportSourceDetails.
        the name of the archive as it exists in object storage


        :param object_name: The object_name of this ImportSourceDetails.
        :type: str
        """
        self._object_name = object_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
